@@ -84,13 +84,18 @@ def raw_data(prompt:str=default_prompt(),model=default_model(),js:dict={}, endpo
         js['prompt'] = prompt
     if 'max_tokens' not in js:
         js['max_tokens'] = default_tokens()
+    js['max_tokens'] = int(js['max_tokens'])
+    pre_max = js['max_tokens']
     token_dist=calculate_token_distribution(max_tokens=js['max_tokens'],prompt=js['prompt'],completion_percentage=40)
     total = len(token_dist['chunks']["data"])
     responses = []
-    pre_max = js['max_tokens']
     for k in range(0,total):
-        js['prompt'] = f'part {k} of {total}:\n{token_dist["chunks"]["data"][k]}'
-        js['max_tokens'] = int(pre_max)-int(count_tokens(js['prompt']))-int(token_dist["prompt"]["used"])
+        bef = int(count_tokens(js['prompt']))
+        formatted_prompt = f'part {k} of {total}:\n{token_dist["chunks"]["data"][k]}'
+        formatted_prompt_length = count_tokens(formatted_prompt)
+        js['prompt'] = formatted_prompt
+        js['max_tokens'] = int(float(token_dist["completion"]["available"] - (formatted_prompt_length - bef))*.90)
+        #js['max_tokens'] = int(js['max_tokens']) -((int(count_tokens(js['prompt']))-int(pre_max)))
         response = requests.post(endpoint, json=create_prompt(js), headers=headers())
         resp = save_response(js, response)
         print(resp)
