@@ -1,4 +1,5 @@
 from nltk.tokenize import word_tokenize
+
 def count_tokens(text):
     """
     Counts the number of tokens in the given text.
@@ -10,25 +11,41 @@ def count_tokens(text):
         int: The number of tokens.
     """
     return len(word_tokenize(text))
+
+def convert_to_percentage(number):
+    if number > 1:
+        return number / 100
+    else:
+        return number
+
 def create_chunks(content, size_per_chunk):
-    words = content.split()
+    tokens = word_tokenize(content)
     chunks = []
     current_chunk = []
-    for word in words:
-        if len(' '.join(current_chunk)) + len(word) > size_per_chunk:
+    current_size = 0
+    for token in tokens:
+        current_size += 1
+        if current_size > size_per_chunk:
             chunks.append(' '.join(current_chunk))
             current_chunk = []
-        current_chunk.append(word)
+            current_size = 1
+        current_chunk.append(token)
     chunks.append(' '.join(current_chunk))
     return chunks
+
 def calculate_token_distribution(max_tokens, prompt:str, completion_percentage:float=40, size_per_chunk:int=None):
+    max_tokens = int(max_tokens)
+    completion_percentage = convert_to_percentage(completion_percentage)
     prompt_length = count_tokens(prompt)
     prompt_percentage = 1 - completion_percentage
-    prompt_available = int(float(max_tokens) * float(prompt_percentage)) - int(prompt_length)
-    completion_available = float(max_tokens) * float(completion_percentage)
-    completion_desired = float(max_tokens) * float(completion_percentage)
-    if size_per_chunk == None:
-        size_per_chunk =float(max_tokens) * float(prompt_percentage)
+    prompt_desired = int(max_tokens * prompt_percentage)
+    prompt_available = max(0, prompt_desired - prompt_length)
+    completion_available = int(max_tokens * completion_percentage)
+    completion_desired = completion_available
+
+    if size_per_chunk is None:
+        size_per_chunk = prompt_length if prompt_length < max_tokens else max_tokens
+
     num_chunks = prompt_length // size_per_chunk + 1 if prompt_length % size_per_chunk > 0 else prompt_length // size_per_chunk
 
     chunked_data = create_chunks(prompt, size_per_chunk)
@@ -41,7 +58,7 @@ def calculate_token_distribution(max_tokens, prompt:str, completion_percentage:f
         "prompt": {
             "available": prompt_available,
             "used": prompt_length,
-            "desired": max_tokens * prompt_percentage
+            "desired": prompt_desired
         },
         "completion": {
             "available": prompt_available + completion_available,
@@ -54,6 +71,4 @@ def calculate_token_distribution(max_tokens, prompt:str, completion_percentage:f
             "data": chunked_data
         }
     }
-
     return token_distribution
-
